%% Demonstrates image processing.
% -------------------------------------------------------------------------
%  See also CannyEnhancer, GaussianDerivative, ColorMapGrayScale, Imager, 
%  ReadImage
% -------------------------------------------------------------------------
%%
% -------------------------------------------------------------------------
%   Copyright (c) 2009 Princeton Satellite Systems, Inc.
%   All rights reserved.
% -------------------------------------------------------------------------

%% Load the image
%---------------
q = ReadImage('MoonAndStars.jpg');

%% Show the derivatives
%---------------------
[dX, dY] = GaussianDerivative( q, 0.05, 0.01 );
Imager(q,[],dX,1);
set(gcf,'name','|X Derivative|');
ColorMapGrayScale;
Imager(q,[],dY,1);
set(gcf,'name','|Y Derivative|');
ColorMapGrayScale;


%% Compute edge strength and direction. This takes the image derivative internally
%---------------------------------------------------------------------
sigma  = 0.05;
eps    = 0.01;
thresh = 0.01;

[eS, eO] = CannyEnhancer( q, sigma, eps, thresh );

Imager(q, [], eS, 1);
set(gcf,'name','Canny Enhancer : Strength');
% Imager(q, [], 256*eO, 1);
% set(gcf,'name','Canny Enhancer : Direction');
% 
% % Thin the edges
% %---------------
% [iN, e0K] = NonMaxSuppression( eO, eS );
% 
% Imager(q, [], iN, 1);
% set(gcf,'name','Non-Maximum Suppression');
% 
% % This finds the curves
% %----------------------
% tauH      = 0.5*max(max(iN));
% tauL      = 0.005*tauH;
% 
% HysteresisThreshold( iN, e0K, tauH, tauL )


%--------------------------------------
% PSS internal file version information
%--------------------------------------
% $Date: 2009-11-04 17:50:02 -0500 (Wed, 04 Nov 2009) $
% $Revision: 17946 $
